@@ -152,7 +152,9 @@ class Cursor:
             A list of artists that can be selected by this cursor.
 
         multiple : bool, default: False
-            Whether multiple artists can be "on" at the same time.
+            Whether multiple artists can be "on" at the same time.  If on,
+            cursor dragging is disabled (so that one does not end up with many
+            cursors on top of one another).
 
         highlight : bool, default: False
             Whether to also highlight the selected artist.  If so,
@@ -169,7 +171,7 @@ class Cursor:
             - True, alias `HoverMode.Persistent`: hovering is active;
               annotations remain in place even after the mouse moves away from
               the artist (until another artist is selected, if *multiple* is
-              False.
+              False).
             - 2, alias `HoverMode.Transient`: hovering is active; annotations
               are removed as soon as the mouse moves away from the artist.
 
@@ -248,6 +250,9 @@ class Cursor:
             connect_pairs += [
                 ("button_press_event", self._on_nonhover_button_press),
             ]
+            if not self._multiple:
+                connect_pairs.append(
+                    ("motion_notify_event", self._on_nonhover_button_press))
         self._disconnectors = [
             partial(canvas.mpl_disconnect, canvas.mpl_connect(*pair))
             for pair in connect_pairs
@@ -368,9 +373,14 @@ class Cursor:
         # Pre-fetch the figure and axes, as callbacks may actually unset them.
         figure = self._get_figure(pi.artist)
         axes = self._get_axes(pi.artist)
-        if axes.get_renderer_cache() is None:
-            figure.canvas.draw()  # Needed by draw_artist below anyways.
-        renderer = axes.get_renderer_cache()
+        get_cached_renderer = (
+            figure.canvas.get_renderer
+            if hasattr(figure.canvas, "get_renderer")
+            else axes.get_renderer_cache)  # matplotlib <3.6.
+        renderer = get_cached_renderer()
+        if renderer is None:
+            figure.canvas.draw()  # Needed below anyways.
+            renderer = get_cached_renderer()
         ann = axes.annotate(
             _pick_info.get_ann_text(*pi), xy=pi.target,
             xytext=(np.nan, np.nan),
@@ -440,7 +450,7 @@ class Cursor:
         elif ann.axes:
             # Fast path, only needed if the annotation has not been immediately
             # removed.
-            figure.draw_artist(ann)
+            ann.draw(renderer)
             figure.canvas.blit()
         # Removal comes after addition so that the fast blitting path works.
         if not self._multiple:
@@ -681,6 +691,12 @@ def cursor(pickables=None, **kwargs):
         Keyword arguments are passed to the `Cursor` constructor.
     """
 
+    # Explicit check to avoid a confusing
+    # "TypeError: Cursor.__init__() got multiple values for argument 'artists'"
+    if "artists" in kwargs:
+        raise TypeError(
+            "cursor() got an unexpected keyword argument 'artists'")
+
     if pickables is None:
         # Do not import pyplot ourselves to avoid forcing the backend.
         plt = sys.modules.get("matplotlib.pyplot")
