@@ -95,7 +95,8 @@ def test_containerartist(ax):
 
 def test_selection_identity_comparison():
     sel0, sel1 = [Selection(artist=None,
-                            target=np.array([0, 0]),
+                            target_=np.array([0, 0]),
+                            index=None,
                             dist=0,
                             annotation=None,
                             extras=[])
@@ -116,31 +117,31 @@ def test_line(ax, plotter):
     cursor = mplcursors.cursor(multiple=True)
     # Far, far away.
     _process_event("__mouse_click__", ax, (0, 1), 1)
-    assert len(cursor.selections) == len(ax.texts) == 0
+    assert len(cursor.selections) == len(ax.figure.artists) == 0
     # On the line.
     _process_event("__mouse_click__", ax, (.1, .4), 1)
-    assert len(cursor.selections) == len(ax.texts) == 1
+    assert len(cursor.selections) == len(ax.figure.artists) == 1
     assert _parse_annotation(
         cursor.selections[0], "foo\nx=(.*)\ny=(.*)") == approx((.1, .4))
     # Not removing it.
     _process_event("__mouse_click__", ax, (0, 1), 3)
-    assert len(cursor.selections) == len(ax.texts) == 1
+    assert len(cursor.selections) == len(ax.figure.artists) == 1
     # Remove the text label; add another annotation.
     artist.set_label(None)
     _process_event("__mouse_click__", ax, (.6, .9), 1)
-    assert len(cursor.selections) == len(ax.texts) == 2
+    assert len(cursor.selections) == len(ax.figure.artists) == 2
     assert _parse_annotation(
         cursor.selections[1], "x=(.*)\ny=(.*)") == approx((.6, .9))
     # Remove both of them (first removing the second one, to test
     # `Selection.__eq__` -- otherwise it is bypassed as `list.remove`
     # checks identity first).
     _process_event(*_get_remove_args(cursor.selections[1]))
-    assert len(cursor.selections) == len(ax.texts) == 1
+    assert len(cursor.selections) == len(ax.figure.artists) == 1
     _process_event(*_get_remove_args(cursor.selections[0]))
-    assert len(cursor.selections) == len(ax.texts) == 0
+    assert len(cursor.selections) == len(ax.figure.artists) == 0
     # Will project on the vertex at (.2, .8).
     _process_event("__mouse_click__", ax, (.2 - .001, .8 + .001), 1)
-    assert len(cursor.selections) == len(ax.texts) == 1
+    assert len(cursor.selections) == len(ax.figure.artists) == 1
 
 
 @pytest.mark.parametrize("plotter",
@@ -150,9 +151,9 @@ def test_scatter(ax, plotter):
     plotter(ax, [0, .5, 1], [0, .5, 1])
     cursor = mplcursors.cursor()
     _process_event("__mouse_click__", ax, (.2, .2), 1)
-    assert len(cursor.selections) == len(ax.texts) == 0
+    assert len(cursor.selections) == len(ax.figure.artists) == 0
     _process_event("__mouse_click__", ax, (.5, .5), 1)
-    assert len(cursor.selections) == len(ax.texts) == 1
+    assert len(cursor.selections) == len(ax.figure.artists) == 1
 
 
 def test_scatter_text(ax):
@@ -176,10 +177,10 @@ def test_steps_pre(ax):
     _process_event("__mouse_click__", ax, (1, 0), 1)
     assert len(cursor.selections) == 0
     _process_event("__mouse_click__", ax, (0, .5), 1)
-    index = cursor.selections[0].target.index
+    index = cursor.selections[0].index
     assert (index.int, index.x, index.y) == approx((0, 0, .5))
     _process_event("__mouse_click__", ax, (.5, 1), 1)
-    index = cursor.selections[0].target.index
+    index = cursor.selections[0].index
     assert (index.int, index.x, index.y) == approx((0, .5, 1))
 
 
@@ -192,13 +193,13 @@ def test_steps_mid(ax):
     _process_event("__mouse_click__", ax, (1, 0), 1)
     assert len(cursor.selections) == 0
     _process_event("__mouse_click__", ax, (.25, 0), 1)
-    index = cursor.selections[0].target.index
+    index = cursor.selections[0].index
     assert (index.int, index.x, index.y) == approx((0, .25, 0))
     _process_event("__mouse_click__", ax, (.5, .5), 1)
-    index = cursor.selections[0].target.index
+    index = cursor.selections[0].index
     assert (index.int, index.x, index.y) == approx((0, .5, .5))
     _process_event("__mouse_click__", ax, (.75, 1), 1)
-    index = cursor.selections[0].target.index
+    index = cursor.selections[0].index
     assert (index.int, index.x, index.y) == approx((0, .75, 1))
 
 
@@ -209,10 +210,10 @@ def test_steps_post(ax):
     _process_event("__mouse_click__", ax, (0, 1), 1)
     assert len(cursor.selections) == 0
     _process_event("__mouse_click__", ax, (.5, 0), 1)
-    index = cursor.selections[0].target.index
+    index = cursor.selections[0].index
     assert (index.int, index.x, index.y) == approx((0, .5, 0))
     _process_event("__mouse_click__", ax, (1, .5), 1)
-    index = cursor.selections[0].target.index
+    index = cursor.selections[0].index
     assert (index.int, index.x, index.y) == approx((0, 1, .5))
 
 
@@ -222,7 +223,7 @@ def test_line_single_point(ax, ls):
     ax.set(xlim=(-1, 1), ylim=(-1, 1))
     cursor = mplcursors.cursor()
     _process_event("__mouse_click__", ax, (.001, .001), 1)
-    assert len(cursor.selections) == len(ax.texts) == (ls == "o")
+    assert len(cursor.selections) == len(ax.figure.artists) == (ls == "o")
     if cursor.selections:
         assert tuple(cursor.selections[0].target) == (0, 0)
 
@@ -235,7 +236,7 @@ def test_nan(ax, plot_args, click, targets):
     ax.plot(*plot_args)
     cursor = mplcursors.cursor()
     _process_event("__mouse_click__", ax, click, 1)
-    assert len(cursor.selections) == len(ax.texts) == len(targets)
+    assert len(cursor.selections) == len(ax.figure.artists) == len(targets)
     for sel, target in zip(cursor.selections, targets):
         assert sel.target == approx(target)
 
@@ -263,20 +264,20 @@ def test_image(ax, origin):
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     sel, = cursor.selections
     assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[1\]") == (1, 0)
-    assert array[sel.target.index] == 1
+    assert array[sel.index] == 1
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     sel, = cursor.selections
     assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0\]") == (0, 0)
-    assert array[sel.target.index] == 0
+    assert array[sel.index] == 0
     _process_event("key_press_event", ax, (.123, .456), "shift+up")
     sel, = cursor.selections
     assert (_parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[(.*)\]")
             == {"upper": (0, 2, 4), "lower": (0, 1, 2)}[origin])
-    assert array[sel.target.index] == {"upper": 4, "lower": 2}[origin]
+    assert array[sel.index] == {"upper": 4, "lower": 2}[origin]
     _process_event("key_press_event", ax, (.123, .456), "shift+down")
     sel, = cursor.selections
     assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0\]") == (0, 0)
-    assert array[sel.target.index] == 0
+    assert array[sel.index] == 0
 
     cursor = mplcursors.cursor()
     # Not picking out-of-axes or of image.
@@ -310,13 +311,14 @@ def test_image_subclass(ax):
 
 
 def test_linecollection(ax):
+    ax.eventplot([])  # This must not raise a division by len([]) == 0.
     ax.eventplot([0, 1])
     cursor = mplcursors.cursor()
     _process_event("__mouse_click__", ax, (0, 0), 1)
     _process_event("__mouse_click__", ax, (.5, 1), 1)
     assert len(cursor.selections) == 0
     _process_event("__mouse_click__", ax, (0, 1), 1)
-    assert cursor.selections[0].target.index == approx((0, .5))
+    assert cursor.selections[0].index == approx((0, .5))
 
 
 def test_patchcollection(ax):
@@ -327,7 +329,7 @@ def test_patchcollection(ax):
     assert len(cursor.selections) == 0
     _process_event("__mouse_click__", ax, (.6, .6), 1)
     # The precision is really bad :(
-    assert cursor.selections[0].target.index == approx((1, 2), abs=2e-2)
+    assert cursor.selections[0].index == approx((1, 2), abs=2e-2)
 
 
 @pytest.mark.parametrize("plotter", [Axes.quiver, Axes.barbs])
@@ -447,14 +449,14 @@ def test_move(ax, plotter):
         _process_event("__mouse_click__", ax, (0, 0), 1)
         _process_event("key_press_event", ax, (.123, .456), "shift+up")
     assert tuple(cursor.selections[0].target) == (0, 0)
-    assert cursor.selections[0].target.index == 0
+    assert cursor.selections[0].index == 0
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     assert tuple(cursor.selections[0].target) == (1, 1)
-    assert cursor.selections[0].target.index == 1
+    assert cursor.selections[0].index == 1
     # Skip through nan.
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     assert tuple(cursor.selections[0].target) == (0, 0)
-    assert cursor.selections[0].target.index == 0
+    assert cursor.selections[0].index == 0
 
 
 @pytest.mark.parametrize(
@@ -477,11 +479,15 @@ def test_hover(ax, hover):
 def test_highlight(ax, plotter):
     plotter(ax, [0, 1], [0, 1])
     ax.set(xlim=(-1, 2), ylim=(-1, 2))
+    base_children = {*ax.artists, *ax.lines, *ax.collections}
     cursor = mplcursors.cursor(highlight=True)
     _process_event("__mouse_click__", ax, (0, 0), 1)
-    assert ax.artists == cursor.selections[0].extras != []
+    # On Matplotlib<=3.4, the highlight went to ax.artists.  On >=3.5, it goes
+    # to its type-specific container.  The construct below handles both cases.
+    assert [*{*ax.artists, *ax.lines, *ax.collections} - base_children] \
+        == cursor.selections[0].extras != []
     _process_event(*_get_remove_args(cursor.selections[0]))
-    assert len(ax.artists) == 0
+    assert len({*ax.artists, *ax.lines, *ax.collections} - base_children) == 0
 
 
 def test_misc_artists_highlight(ax):
@@ -571,18 +577,18 @@ def test_removed_artist(ax):
     cursor = mplcursors.cursor()
     l.remove()
     _process_event("__mouse_click__", ax, (.5, .5), 1)
-    assert len(cursor.selections) == len(ax.texts) == 0
+    assert len(cursor.selections) == len(ax.figure.artists) == 0
 
 
 def test_remove_cursor(ax):
     ax.plot([0, 1])
     cursor = mplcursors.cursor()
     _process_event("__mouse_click__", ax, (.5, .5), 1)
-    assert len(cursor.selections) == len(ax.texts) == 1
+    assert len(cursor.selections) == len(ax.figure.artists) == 1
     cursor.remove()
-    assert len(cursor.selections) == len(ax.texts) == 0
+    assert len(cursor.selections) == len(ax.figure.artists) == 0
     _process_event("__mouse_click__", ax, (.5, .5), 1)
-    assert len(cursor.selections) == len(ax.texts) == 0
+    assert len(cursor.selections) == len(ax.figure.artists) == 0
 
 
 def test_keys(ax):
@@ -604,6 +610,11 @@ def test_keys(ax):
     ax.figure.canvas.draw()
     _process_event(*_get_remove_args(cursor.selections[0]))
     assert len(cursor.selections) == 1
+    # (Moving becomes inactive.)
+    old_target = cursor.selections[0].target
+    _process_event("key_press_event", ax, (.123, .456), "shift+left")
+    new_target = cursor.selections[0].target
+    assert (old_target == new_target).all()
     # Reenable it.
     _process_event("key_press_event", ax, (.123, .456), "e")
     assert cursor.enabled
@@ -639,21 +650,21 @@ def test_multiple_figures(ax):
     # Add something on the first axes.
     _process_event("__mouse_click__", ax1, (.5, .5), 1)
     assert len(cursor.selections) == 1
-    assert len(ax1.texts) == 1
-    assert len(ax2.texts) == 0
+    assert len(ax1.figure.artists) == 1
+    assert len(ax2.figure.artists) == 0
     # Right-clicking on the second axis doesn't remove it.
     remove_args = [*_get_remove_args(cursor.selections[0])]
     remove_args[remove_args.index(ax1)] = ax2
     _process_event(*remove_args)
     assert len(cursor.selections) == 1
-    assert len(ax1.texts) == 1
-    assert len(ax2.texts) == 0
+    assert len(ax1.figure.artists) == 1
+    assert len(ax2.figure.artists) == 0
     # Remove it, add something on the second.
     _process_event(*_get_remove_args(cursor.selections[0]))
     _process_event("__mouse_click__", ax2, (.5, .5), 1)
     assert len(cursor.selections) == 1
-    assert len(ax1.texts) == 0
-    assert len(ax2.texts) == 1
+    assert len(ax1.figure.artists) == 0
+    assert len(ax2.figure.artists) == 1
 
 
 def test_gc(ax):
